@@ -1,15 +1,13 @@
-'''
+"""
 Functions to clean and standardise TCR gene data.
-'''
+"""
 
 
-from ._main import (
-    standardise
-)
+from ._main import standardise, query
 
 
 def standardize(*args, **kwargs):
-    '''
+    """
     Alias for :py:func:`tidytcells.tcr.standardise`.
-    '''
-    return standardise(*args, **kwargs)
\ No newline at end of file
+    """
+    return standardise(*args, **kwargs)
